@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: read_data.h,v 1.12 2005/02/15 12:48:32 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,15 +25,14 @@
 #define __GLIBTOP_READ_DATA_H__
 
 #include <glibtop.h>
-#include <glibtop/error.h>
 
-BEGIN_LIBGTOP_DECLS
+G_BEGIN_DECLS
 
 #define glibtop_read_data()	glibtop_read_data_r(glibtop_global_server)
 
 void *glibtop_read_data_l (glibtop *server);
 void *glibtop_read_data_s (glibtop *server);
 
-END_LIBGTOP_DECLS
+G_END_DECLS
 
 #endif
