@@ -1,4 +1,4 @@
-/* $Id: sysinfo.h,v 1.14 2005/06/07 09:54:43 bdejean Exp $ */
+/* $Id: sysinfo.h,v 1.15 2006/12/03 18:21:01 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -50,7 +50,8 @@ struct _glibtop_entry
 
 struct _glibtop_sysinfo
 {
-	guint64	flags, ncpu;
+	guint64	flags;
+	guint64 ncpu;
 	glibtop_entry cpuinfo [GLIBTOP_NCPU];
 };
 
