@@ -1,4 +1,4 @@
-/* $Id: open.c,v 1.29 2006/07/27 09:23:32 bdejean Exp $ */
+/* $Id: open.c,v 1.30 2006/08/10 11:21:39 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -91,9 +91,11 @@ glibtop_open_s (glibtop *server, const char *program_name,
 
 	server->ncpu = MIN(GLIBTOP_NCPU - 1, server->real_ncpu);
 
-	glibtop_warn_r(server,
-		       "This machine has %d CPUs, "
-		       "%d are being monitored.",
-		       server->real_ncpu + 1,
-		       server->ncpu + 1);
+	if (server->real_ncpu != server->ncpu) {
+		glibtop_warn_r(server,
+			       "This machine has %d CPUs, "
+			       "%d are being monitored.",
+			       server->real_ncpu + 1,
+			       server->ncpu + 1);
+	}
 }
