@@ -1,4 +1,4 @@
-/* $Id: open_suid.c,v 1.10 2004/06/09 18:52:22 bdejean Exp $ */
+/* $Id: open_suid.c,v 1.12 2005/12/12 09:38:12 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,9 +21,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
-
+#include <glibtop/init_hooks.h>
 #include <glibtop_suid.h>
 
 #include <unistd.h>
@@ -35,7 +36,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
