@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: proctime.c,v 1.15 2005/12/12 09:38:12 jamesh Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -23,6 +21,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/proctime.h>
 
@@ -38,48 +37,44 @@ static const unsigned long _glibtop_sysdeps_proc_time =
 
 /* Init function. */
 
-int
+void
 glibtop_init_proc_time_p (glibtop *server)
 {
-    server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
-
-    return 0;
+	server->sysdeps.proc_time = _glibtop_sysdeps_proc_time;
 }
 
 /* Provides detailed information about a process. */
 
-int
+void
 glibtop_get_proc_time_p (glibtop *server, glibtop_proc_time *buf,
 			 pid_t pid)
 {
-    struct user u;
-    int ret;
+	struct user u;
+	int ret;
 
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_TIME, 0);
-	
-    memset (buf, 0, sizeof (glibtop_proc_time));
-	
-    /* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_PROC_TIME, 0);
 
-    glibtop_suid_enter (server);
-	
-    ret = table (TBL_UAREA, pid, (char *) &u, 1,
-		 sizeof (struct user));
-		     
-    glibtop_suid_leave (server);
-		     
-    /* !!! END OF SUID ROOT PART !!! */
-	
-    if (ret != 1) return -1;
+	memset (buf, 0, sizeof (glibtop_proc_time));
 
-    buf->start_time = u.u_start.tv_sec;
-	
-    buf->utime = u.u_ru.ru_utime.tv_sec;
-    buf->stime = u.u_ru.ru_stime.tv_sec;
-    buf->cutime = u.u_cru.ru_utime.tv_sec;
-    buf->cstime = u.u_cru.ru_stime.tv_sec;
+	/* !!! THE FOLLOWING CODE RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
-    buf->flags = _glibtop_sysdeps_proc_time;	
+	glibtop_suid_enter (server);
 
-    return 0;
+	ret = table (TBL_UAREA, pid, (char *) &u, 1,
+		     sizeof (struct user));
+
+	glibtop_suid_leave (server);
+
+	/* !!! END OF SUID ROOT PART !!! */
+
+	if (ret != 1) return;
+
+	buf->start_time = u.u_start.tv_sec;
+
+	buf->utime = u.u_ru.ru_utime.tv_sec;
+	buf->stime = u.u_ru.ru_stime.tv_sec;
+	buf->cutime = u.u_cru.ru_utime.tv_sec;
+	buf->cstime = u.u_cru.ru_stime.tv_sec;
+
+	buf->flags = _glibtop_sysdeps_proc_time;
 }
